===========
django_xray
===========


Status
======
.. image:: https://travis-ci.org/mvantellingen/django-xray.svg?branch=master
    :target: https://travis-ci.org/mvantellingen/django-xray

.. image:: http://codecov.io/github/mvantellingen/django-xray/coverage.svg?branch=master
    :target: http://codecov.io/github/mvantellingen/django-xray?branch=master

.. image:: https://img.shields.io/pypi/v/django-xray.svg
    :target: https://pypi.python.org/pypi/django-xray/


Installation
============

.. code-block:: shell

   pip install django_xray
